@@ -1,15 +1,15 @@
-
 #' @title Launch an RStudio addin which allows to schedule an Rscript interactively.
 #' @description Launch an RStudio addin which allows to schedule an Rscript interactively.
 #' 
-#' @param RscriptRepository path to the folder where R scripts will be copied to and launched. Defaults to the extdata folder in the cronR R library
+#' @param RscriptRepository path to the folder where R scripts will be copied to and launched from, and by default log files will be written to.
+#' Defaults to the current working directory or in case it is set, the path set in the \code{CRON_LIVE} environment variable.
 #' @return the return of \code{\link[shiny]{runGadget}}
 #' @export
 #' @examples 
 #' \dontrun{
 #' cron_rstudioaddin()
 #' }
-cron_rstudioaddin <- function(RscriptRepository) {
+cron_rstudioaddin <- function(RscriptRepository = Sys.getenv("CRON_LIVE", unset = getwd())) {
   
   cron_current <- function(){
     x <- try(parse_crontab(), silent = TRUE)
@@ -22,21 +22,7 @@ cron_rstudioaddin <- function(RscriptRepository) {
   requireNamespace("shiny")
   requireNamespace("miniUI")
   requireNamespace("shinyFiles")
-  current_repo <- file.path(system.file("extdata", package="cronR"), ".RscriptRepository.rds")
-  if(file.access(dirname(current_repo), mode = 2) == -1){
-    ## No access to the root folder by this user, take tempfolder - will not persist across R sessions
-    current_repo <- file.path(tempdir(), ".RscriptRepository.rds")
-  }
-  if(missing(RscriptRepository)){
-    if(file.exists(current_repo)){
-      RscriptRepository <- readRDS(file = current_repo)
-    }else{
-      RscriptRepository <- system.file("extdata", package="cronR")
-      RscriptRepository <- getwd()
-      saveRDS(RscriptRepository, file = current_repo)
-    }
-  }
-  
+
   check <- NULL
   
   ui <- miniUI::miniPage(
@@ -151,14 +137,11 @@ cron_rstudioaddin <- function(RscriptRepository) {
     #                    multiple = FALSE)
     # })
     
-    # When path to Rscript repository has been changed
+    # when path to Rscript repository has been changed, check for existence of path and write permissions,
+    # and normalize RscriptRepository path in parent environment.
     shiny::observeEvent(input$rscript_repository, {
       RscriptRepository <<- normalizePath(input$rscript_repository, winslash = "/")
-      if(file.exists(RscriptRepository) && file.info(RscriptRepository)$isdir == TRUE){
-        saveRDS(RscriptRepository, file = current_repo)
-      }else {
-        message(sprintf("RscriptRepository %s does not exist, make sure this is an existing directory without spaces", RscriptRepository))
-      }
+      verify_rscript_path(RscriptRepository)
     })
     
     ###########################
@@ -191,10 +174,15 @@ cron_rstudioaddin <- function(RscriptRepository) {
       if(length(grep(" ", RscriptRepository)) > 0){
         warning(sprintf("It is advised that the RscriptRepository does not contain spaces, change argument %s to another location on your drive which contains no spaces", RscriptRepository))
       }
+      
+      if (!file.exists(RscriptRepository)) {
+        stop(sprintf("The specified Rscript repository path, at %s, does not exist. Please set it to an existing directory.", RscriptRepository))
+      }
+      
       runme <- getSelectedFile(inputui = input$fileSelect)
       myscript <- paste0(RscriptRepository, "/", basename(runme))
       if(runme != myscript){
-        done <-  file.copy(runme, myscript, overwrite = TRUE)
+        done <- file.copy(runme, myscript, overwrite = TRUE)
         if(!done){
           stop(sprintf('Copying file %s to %s failed. Do you have access rights to %s?', file.path(runme, input$file$name), myscript, dirname(myscript)))
         }  
@@ -304,3 +292,11 @@ cron_rstudioaddin <- function(RscriptRepository) {
   shiny::runGadget(ui, server, viewer = viewer)
 }
 
+verify_rscript_path <- function(RscriptRepository) {
+  # first check whether path exists; if it does, then check whether you have write permission.
+  if(is.na(file.info(RscriptRepository)$isdir)){
+    warning(sprintf("The specified Rscript repository path %s does not exist, make sure this is an existing directory without spaces.", RscriptRepository))
+  } else if (as.logical(file.access(RscriptRepository, mode = 2))) {
+    warning(sprintf("You do not have write access to the specified Rscript repository path, %s.", RscriptRepository))
+  }
+}
